@@ -5,15 +5,23 @@
 #include "node.h"
 #include "causalTreeproto.h"
 
-static void
-free_split(pSplit spl)
+static void free_split(pSplit spl)
 {
     if (spl) {
-	free_split(spl->nextsplit);
-	Free(spl);
+        free_split(spl->nextsplit); 
+        free(spl);                  
     }
 }
 
+// static void
+// free_split(pSplit spl)
+// {
+//     if (spl) {
+// 	free_split(spl->nextsplit);
+// 	Free(spl);
+//     }
+// }
+
 /* use freenode if the tree was CALLOC-ed, from xval.c */
 void
 free_tree(pNode node, int freenode)
@@ -26,7 +34,7 @@ free_tree(pNode node, int freenode)
     free_split(node->surrogate);
     free_split(node->primary);
     if (freenode == 1)
-	Free(node);
+	free(node);
     else {
        /* don't point to things I just freed */
 	node->primary = (pSplit) NULL;
